@@ -191,10 +191,10 @@ class Metadata:
     @staticmethod
     def getKey():
         key = "Default"
-        secPath = ResMan.joinPath(ResMan.root(), "secretPass")
+        secPath = ResMan.root("secretPass")
         if (os.path.exists(secPath)):
             with open(secPath, "r") as f:
-                key = f.read()
+                key = f.read().strip()
         return key
 
     @staticmethod
