@@ -35,6 +35,10 @@ class ProjectBuilder:
                 "SECRETS": {}
             }
 
+            if (not os.exists(ResMan.root("adminSettings.json"))):
+                Logger.bold("SKIPPING BUILD")
+                return True
+
             #build controllers
             ControllerBuilder.build(self)
 
